Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
MonochromeMode = false
)
Functions ¶
func GetGenerationColor ¶
GetGenerationColor returns a color based on generation
func ToggleMonochromeMode ¶
func ToggleMonochromeMode()
Types ¶
type MenuModel ¶
type MenuModel struct {
// contains filtered or unexported fields
}
MenuModel represents the main menu state
func NewMenuModel ¶
func NewMenuModel() MenuModel
NewMenuModel creates a new MenuModel with default choices and dimensions
func (*MenuModel) SetDimensions ¶
SetDimensions allows setting the menu dimensions when returning from a game
type SimulationModel ¶
type SimulationModel struct {
FocusMode bool
// contains filtered or unexported fields
}
SimulationModel represents the state of the cellular automaton simulation
func NewSimulationModel ¶
func NewSimulationModel(automatonType string) SimulationModel
NewSimulationModel creates a new SimulationModel for the specified automaton type
func (SimulationModel) Init ¶
func (m SimulationModel) Init() tea.Cmd
Init initializes the simulation model, setting up the grid and starting the tick
func (SimulationModel) View ¶
func (m SimulationModel) View() string
View renders the current state of the simulation
Click to show internal directories.
Click to hide internal directories.